class Item

  include MongoMapper::Document
  
  key :_type, String
  
  key :name, String, :required => true, :index => true
  key :full_name, String, :required => true, :index => true
    
  key :parent_id, ObjectId, :index => true
  
  key_i18n :title, String, :required => true
   
  key :position, Integer, :required => true
  key :is_published, Boolean, :required => true, :default => true, :index => true
 
  validates_format_of :name, :with => /^[0-9a-zA-Z\-_]+$/
  validates_uniqueness_of :name, :scope => :parent_id
  
  belongs_to :parent, :class_name => "Item", :foreign_key => :parent_id
  many :children, :class_name => "Item", :foreign_key => :parent_id, :dependent => :destroy
  
  before_validation :setup_default_value
  
  attr_accessor :parent_name
  def parent_name
    @parent_name || self.parent.name
  end
  
  def self.find_by_name(item_name)
    Item.first(:conditions => { :name => item_name, :is_published => true })
  end
  
  def ancestors
    node, nodes = self, []
    nodes << node = node.parent while !node.parent.blank?
    nodes.reverse
  end

  def url
    urls = ancestors.map{ |a| a.name } << self.name
    urls.delete("root")
    "/#{urls.join("/")}"
  end
  
  protected
  
  def setup_default_value
    if self.position.blank?
      max_page = Page.last(:order => 'position')
      self.position = (max_page)? max_page.position.to_i + 1 : 1
    end
    
    if self.parent_name.blank?
      self.parent_name = nil
      self.parent_id = nil
    else
      self.parent_id = Item.find_by_name( self.parent_name ).id
    end
    
    full_node = self.ancestors.map{ |a| a.name }.push( self.name )
    full_node.shift if full_node.size >= 2
    self.full_name = full_node.join("/")
  end
    
end